from setuptools import setup, find_packages
import os

def read_file(filename):
    with open(os.path.join(os.path.dirname(__file__), filename), 'r', encoding='utf-8') as f:
        return f.read()

setup(
    name='MagicConvert',
    version='0.1.0',
    packages=find_packages(),
    include_package_data=True,
    package_data={'MagicConvert': []},
    python_requires='>=3.6',
    install_requires=[
        'mammoth>=1.4.0',
        'markdownify>=0.11.0',
        'pandas>=1.0.0',
        'pdfminer.six>=20200517',
        'python-pptx>=0.6.18',
        'puremagic>=1.11',
        'requests>=2.25.0',
        'beautifulsoup4>=4.9.0',
        'charset-normalizer>=2.0.0',
        'Pillow>=8.0.0',
        'pytesseract>=0.3.0',
        'openpyxl>=3.0.0'
    ],
    project_urls = {
        'Source': 'https://github.com/MuhammadNoman76/MagicConvert',
        'Issue Tracker': 'https://github.com/MuhammadNoman76/MagicConvert/issues',
        'LinkedIn': 'https://www.linkedin.com/in/muhammad-noman76',
    },
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Intended Audience :: Developers',
        'Intended Audience :: Science/Research',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Topic :: Scientific/Engineering :: Artificial Intelligence',
        'Topic :: Text Processing :: General',
        'Topic :: Office/Business',
        'Topic :: Software Development :: Libraries :: Python Modules'
    ],
    author='Muhammad Noman',
    author_email='muhammadnomanshafiq76@gmail.com',
    description='MagicConvert is a Python library that converts various document formats (PDF, DOCX, XLSX, PPTX, HTML, Images) to markdown text. Features include OCR support, automatic format detection, and URL/file stream handling.',
    long_description=read_file('README.md'),
    long_description_content_type='text/markdown',
    license='MIT',
    license_files=['LICENSE'],
    keywords='document-conversion markdown ocr pdf-to-markdown docx-to-markdown xlsx-to-markdown pptx-to-markdown html-to-markdown image-to-text python-library text-extraction document-processing format-detection tesseract-ocr file-conversion text-processing',
    url='https://github.com/MuhammadNoman76/MagicConvert'
)